Class: TimeLogic::Api::DstResponse
- Inherits:
-
Object
- Object
- TimeLogic::Api::DstResponse
- Defined in:
- lib/timelogic-api/models/dst_response.rb
Instance Attribute Summary collapse
-
#day_full ⇒ Object
Returns the value of attribute day_full.
-
#day_number ⇒ Object
Returns the value of attribute day_number.
-
#day_short ⇒ Object
Returns the value of attribute day_short.
-
#dst_active ⇒ Object
Returns the value of attribute dst_active.
-
#formatted ⇒ Object
Returns the value of attribute formatted.
-
#human ⇒ Object
Returns the value of attribute human.
-
#iso_local ⇒ Object
Returns the value of attribute iso_local.
-
#next_transition ⇒ Object
Returns the value of attribute next_transition.
-
#rfc2822 ⇒ Object
Returns the value of attribute rfc2822.
-
#timezone ⇒ Object
Returns the value of attribute timezone.
-
#unix ⇒ Object
Returns the value of attribute unix.
-
#unix_ms ⇒ Object
Returns the value of attribute unix_ms.
-
#utc ⇒ Object
Returns the value of attribute utc.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DstResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DstResponse
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/timelogic-api/models/dst_response.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TimeLogic::Api::DstResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TimeLogic::Api::DstResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'unix') self.unix = attributes[:'unix'] else self.unix = nil end if attributes.key?(:'unix_ms') self.unix_ms = attributes[:'unix_ms'] else self.unix_ms = nil end if attributes.key?(:'utc') self.utc = attributes[:'utc'] else self.utc = nil end if attributes.key?(:'iso_local') self.iso_local = attributes[:'iso_local'] else self.iso_local = nil end if attributes.key?(:'rfc2822') self.rfc2822 = attributes[:'rfc2822'] else self.rfc2822 = nil end if attributes.key?(:'human') self.human = attributes[:'human'] else self.human = nil end if attributes.key?(:'day_number') self.day_number = attributes[:'day_number'] else self.day_number = nil end if attributes.key?(:'day_short') self.day_short = attributes[:'day_short'] else self.day_short = nil end if attributes.key?(:'day_full') self.day_full = attributes[:'day_full'] else self.day_full = nil end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end if attributes.key?(:'formatted') self.formatted = attributes[:'formatted'] end if attributes.key?(:'dst_active') self.dst_active = attributes[:'dst_active'] else self.dst_active = nil end if attributes.key?(:'next_transition') self.next_transition = attributes[:'next_transition'] end end |
Instance Attribute Details
#day_full ⇒ Object
Returns the value of attribute day_full.
34 35 36 |
# File 'lib/timelogic-api/models/dst_response.rb', line 34 def day_full @day_full end |
#day_number ⇒ Object
Returns the value of attribute day_number.
30 31 32 |
# File 'lib/timelogic-api/models/dst_response.rb', line 30 def day_number @day_number end |
#day_short ⇒ Object
Returns the value of attribute day_short.
32 33 34 |
# File 'lib/timelogic-api/models/dst_response.rb', line 32 def day_short @day_short end |
#dst_active ⇒ Object
Returns the value of attribute dst_active.
40 41 42 |
# File 'lib/timelogic-api/models/dst_response.rb', line 40 def dst_active @dst_active end |
#formatted ⇒ Object
Returns the value of attribute formatted.
38 39 40 |
# File 'lib/timelogic-api/models/dst_response.rb', line 38 def formatted @formatted end |
#human ⇒ Object
Returns the value of attribute human.
28 29 30 |
# File 'lib/timelogic-api/models/dst_response.rb', line 28 def human @human end |
#iso_local ⇒ Object
Returns the value of attribute iso_local.
24 25 26 |
# File 'lib/timelogic-api/models/dst_response.rb', line 24 def iso_local @iso_local end |
#next_transition ⇒ Object
Returns the value of attribute next_transition.
42 43 44 |
# File 'lib/timelogic-api/models/dst_response.rb', line 42 def next_transition @next_transition end |
#rfc2822 ⇒ Object
Returns the value of attribute rfc2822.
26 27 28 |
# File 'lib/timelogic-api/models/dst_response.rb', line 26 def rfc2822 @rfc2822 end |
#timezone ⇒ Object
Returns the value of attribute timezone.
36 37 38 |
# File 'lib/timelogic-api/models/dst_response.rb', line 36 def timezone @timezone end |
#unix ⇒ Object
Returns the value of attribute unix.
18 19 20 |
# File 'lib/timelogic-api/models/dst_response.rb', line 18 def unix @unix end |
#unix_ms ⇒ Object
Returns the value of attribute unix_ms.
20 21 22 |
# File 'lib/timelogic-api/models/dst_response.rb', line 20 def unix_ms @unix_ms end |
#utc ⇒ Object
Returns the value of attribute utc.
22 23 24 |
# File 'lib/timelogic-api/models/dst_response.rb', line 22 def utc @utc end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/timelogic-api/models/dst_response.rb', line 340 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TimeLogic::Api.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/timelogic-api/models/dst_response.rb', line 64 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/timelogic-api/models/dst_response.rb', line 45 def self.attribute_map { :'unix' => :'unix', :'unix_ms' => :'unix_ms', :'utc' => :'utc', :'iso_local' => :'iso_local', :'rfc2822' => :'rfc2822', :'human' => :'human', :'day_number' => :'day_number', :'day_short' => :'day_short', :'day_full' => :'day_full', :'timezone' => :'timezone', :'formatted' => :'formatted', :'dst_active' => :'dst_active', :'next_transition' => :'next_transition' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/timelogic-api/models/dst_response.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
97 98 99 100 101 |
# File 'lib/timelogic-api/models/dst_response.rb', line 97 def self.openapi_all_of [ :'TimePayload' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 93 94 |
# File 'lib/timelogic-api/models/dst_response.rb', line 88 def self.openapi_nullable Set.new([ :'iso_local', :'timezone', :'next_transition' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/timelogic-api/models/dst_response.rb', line 69 def self.openapi_types { :'unix' => :'Integer', :'unix_ms' => :'Integer', :'utc' => :'Time', :'iso_local' => :'String', :'rfc2822' => :'String', :'human' => :'String', :'day_number' => :'Integer', :'day_short' => :'String', :'day_full' => :'String', :'timezone' => :'String', :'formatted' => :'String', :'dst_active' => :'Boolean', :'next_transition' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/timelogic-api/models/dst_response.rb', line 283 def ==(o) return true if self.equal?(o) self.class == o.class && unix == o.unix && unix_ms == o.unix_ms && utc == o.utc && iso_local == o.iso_local && rfc2822 == o.rfc2822 && human == o.human && day_number == o.day_number && day_short == o.day_short && day_full == o.day_full && timezone == o.timezone && formatted == o.formatted && dst_active == o.dst_active && next_transition == o.next_transition end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/timelogic-api/models/dst_response.rb', line 411 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/timelogic-api/models/dst_response.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/timelogic-api/models/dst_response.rb', line 309 def hash [unix, unix_ms, utc, iso_local, rfc2822, human, day_number, day_short, day_full, timezone, formatted, dst_active, next_transition].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/timelogic-api/models/dst_response.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @unix.nil? invalid_properties.push('invalid value for "unix", unix cannot be nil.') end if @unix_ms.nil? invalid_properties.push('invalid value for "unix_ms", unix_ms cannot be nil.') end if @utc.nil? invalid_properties.push('invalid value for "utc", utc cannot be nil.') end if @rfc2822.nil? invalid_properties.push('invalid value for "rfc2822", rfc2822 cannot be nil.') end if @human.nil? invalid_properties.push('invalid value for "human", human cannot be nil.') end if @day_number.nil? invalid_properties.push('invalid value for "day_number", day_number cannot be nil.') end if @day_number > 7 invalid_properties.push('invalid value for "day_number", must be smaller than or equal to 7.') end if @day_number < 1 invalid_properties.push('invalid value for "day_number", must be greater than or equal to 1.') end if @day_short.nil? invalid_properties.push('invalid value for "day_short", day_short cannot be nil.') end if @day_full.nil? invalid_properties.push('invalid value for "day_full", day_full cannot be nil.') end if @dst_active.nil? invalid_properties.push('invalid value for "dst_active", dst_active cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
387 388 389 |
# File 'lib/timelogic-api/models/dst_response.rb', line 387 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/timelogic-api/models/dst_response.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
381 382 383 |
# File 'lib/timelogic-api/models/dst_response.rb', line 381 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/timelogic-api/models/dst_response.rb', line 247 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @unix.nil? return false if @unix_ms.nil? return false if @utc.nil? return false if @rfc2822.nil? return false if @human.nil? return false if @day_number.nil? return false if @day_number > 7 return false if @day_number < 1 return false if @day_short.nil? return false if @day_full.nil? return false if @dst_active.nil? true end |