Class: TimeLogic::Api::TimezoneResolvedResponse
- Inherits:
-
Object
- Object
- TimeLogic::Api::TimezoneResolvedResponse
- Defined in:
- lib/timelogic-api/models/timezone_resolved_response.rb
Overview
Standard single-target timezone resolution payload.
Instance Attribute Summary collapse
-
#day_full ⇒ Object
Returns the value of attribute day_full.
-
#day_number ⇒ Object
Returns the value of attribute day_number.
-
#day_short ⇒ Object
Returns the value of attribute day_short.
-
#dst ⇒ Object
Returns the value of attribute dst.
-
#formatted ⇒ Object
Returns the value of attribute formatted.
-
#human ⇒ Object
Returns the value of attribute human.
-
#iso_local ⇒ Object
Returns the value of attribute iso_local.
-
#offset ⇒ Object
Returns the value of attribute offset.
-
#rfc2822 ⇒ Object
Returns the value of attribute rfc2822.
-
#timezone ⇒ Object
Returns the value of attribute timezone.
-
#unix ⇒ Object
Returns the value of attribute unix.
-
#unix_ms ⇒ Object
Returns the value of attribute unix_ms.
-
#utc ⇒ Object
Returns the value of attribute utc.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TimezoneResolvedResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TimezoneResolvedResponse
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TimeLogic::Api::TimezoneResolvedResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TimeLogic::Api::TimezoneResolvedResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'unix') self.unix = attributes[:'unix'] else self.unix = nil end if attributes.key?(:'unix_ms') self.unix_ms = attributes[:'unix_ms'] else self.unix_ms = nil end if attributes.key?(:'utc') self.utc = attributes[:'utc'] else self.utc = nil end if attributes.key?(:'iso_local') self.iso_local = attributes[:'iso_local'] else self.iso_local = nil end if attributes.key?(:'rfc2822') self.rfc2822 = attributes[:'rfc2822'] else self.rfc2822 = nil end if attributes.key?(:'human') self.human = attributes[:'human'] else self.human = nil end if attributes.key?(:'day_number') self.day_number = attributes[:'day_number'] else self.day_number = nil end if attributes.key?(:'day_short') self.day_short = attributes[:'day_short'] else self.day_short = nil end if attributes.key?(:'day_full') self.day_full = attributes[:'day_full'] else self.day_full = nil end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end if attributes.key?(:'formatted') self.formatted = attributes[:'formatted'] end if attributes.key?(:'offset') self.offset = attributes[:'offset'] else self.offset = nil end if attributes.key?(:'dst') self.dst = attributes[:'dst'] else self.dst = nil end end |
Instance Attribute Details
#day_full ⇒ Object
Returns the value of attribute day_full.
35 36 37 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 35 def day_full @day_full end |
#day_number ⇒ Object
Returns the value of attribute day_number.
31 32 33 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 31 def day_number @day_number end |
#day_short ⇒ Object
Returns the value of attribute day_short.
33 34 35 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 33 def day_short @day_short end |
#dst ⇒ Object
Returns the value of attribute dst.
43 44 45 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 43 def dst @dst end |
#formatted ⇒ Object
Returns the value of attribute formatted.
39 40 41 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 39 def formatted @formatted end |
#human ⇒ Object
Returns the value of attribute human.
29 30 31 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 29 def human @human end |
#iso_local ⇒ Object
Returns the value of attribute iso_local.
25 26 27 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 25 def iso_local @iso_local end |
#offset ⇒ Object
Returns the value of attribute offset.
41 42 43 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 41 def offset @offset end |
#rfc2822 ⇒ Object
Returns the value of attribute rfc2822.
27 28 29 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 27 def rfc2822 @rfc2822 end |
#timezone ⇒ Object
Returns the value of attribute timezone.
37 38 39 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 37 def timezone @timezone end |
#unix ⇒ Object
Returns the value of attribute unix.
19 20 21 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 19 def unix @unix end |
#unix_ms ⇒ Object
Returns the value of attribute unix_ms.
21 22 23 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 21 def unix_ms @unix_ms end |
#utc ⇒ Object
Returns the value of attribute utc.
23 24 25 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 23 def utc @utc end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 347 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TimeLogic::Api.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 65 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 46 def self.attribute_map { :'unix' => :'unix', :'unix_ms' => :'unix_ms', :'utc' => :'utc', :'iso_local' => :'iso_local', :'rfc2822' => :'rfc2822', :'human' => :'human', :'day_number' => :'day_number', :'day_short' => :'day_short', :'day_full' => :'day_full', :'timezone' => :'timezone', :'formatted' => :'formatted', :'offset' => :'offset', :'dst' => :'dst' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 323 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
97 98 99 100 101 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 97 def self.openapi_all_of [ :'TimePayload' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 94 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 89 def self.openapi_nullable Set.new([ :'iso_local', :'timezone', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 70 def self.openapi_types { :'unix' => :'Integer', :'unix_ms' => :'Integer', :'utc' => :'Time', :'iso_local' => :'String', :'rfc2822' => :'String', :'human' => :'String', :'day_number' => :'Integer', :'day_short' => :'String', :'day_full' => :'String', :'timezone' => :'String', :'formatted' => :'String', :'offset' => :'Integer', :'dst' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && unix == o.unix && unix_ms == o.unix_ms && utc == o.utc && iso_local == o.iso_local && rfc2822 == o.rfc2822 && human == o.human && day_number == o.day_number && day_short == o.day_short && day_full == o.day_full && timezone == o.timezone && formatted == o.formatted && offset == o.offset && dst == o.dst end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 418 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
310 311 312 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 310 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
316 317 318 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 316 def hash [unix, unix_ms, utc, iso_local, rfc2822, human, day_number, day_short, day_full, timezone, formatted, offset, dst].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 197 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @unix.nil? invalid_properties.push('invalid value for "unix", unix cannot be nil.') end if @unix_ms.nil? invalid_properties.push('invalid value for "unix_ms", unix_ms cannot be nil.') end if @utc.nil? invalid_properties.push('invalid value for "utc", utc cannot be nil.') end if @rfc2822.nil? invalid_properties.push('invalid value for "rfc2822", rfc2822 cannot be nil.') end if @human.nil? invalid_properties.push('invalid value for "human", human cannot be nil.') end if @day_number.nil? invalid_properties.push('invalid value for "day_number", day_number cannot be nil.') end if @day_number > 7 invalid_properties.push('invalid value for "day_number", must be smaller than or equal to 7.') end if @day_number < 1 invalid_properties.push('invalid value for "day_number", must be greater than or equal to 1.') end if @day_short.nil? invalid_properties.push('invalid value for "day_short", day_short cannot be nil.') end if @day_full.nil? invalid_properties.push('invalid value for "day_full", day_full cannot be nil.') end if @offset.nil? invalid_properties.push('invalid value for "offset", offset cannot be nil.') end if @dst.nil? invalid_properties.push('invalid value for "dst", dst cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
394 395 396 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 394 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 400 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
388 389 390 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 388 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/timelogic-api/models/timezone_resolved_response.rb', line 253 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @unix.nil? return false if @unix_ms.nil? return false if @utc.nil? return false if @rfc2822.nil? return false if @human.nil? return false if @day_number.nil? return false if @day_number > 7 return false if @day_number < 1 return false if @day_short.nil? return false if @day_full.nil? return false if @offset.nil? return false if @dst.nil? true end |